==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/LogAnalyticsConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.LogAnalyticsConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property customerId
 * @property sharedKey
 */
public data class LogAnalyticsConfigurationArgs(
    public val customerId: Output<String>? = null,
    public val sharedKey: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.LogAnalyticsConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.LogAnalyticsConfigurationArgs =
        com.pulumi.azurenative.web.inputs.LogAnalyticsConfigurationArgs.builder()
            .customerId(customerId?.applyValue({ args0 -> args0 }))
            .sharedKey(sharedKey?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LogAnalyticsConfigurationArgs].
 */
@PulumiTagMarker
public class LogAnalyticsConfigurationArgsBuilder internal constructor() {
    private var customerId: Output<String>? = null

    private var sharedKey: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("wdixfjheakqsusxx")
    public suspend fun customerId(`value`: Output<String>) {
        this.customerId = value
    }

    /**
     * @param value
     */
    @JvmName("xukfsrqgwdyxyjlm")
    public suspend fun sharedKey(`value`: Output<String>) {
        this.sharedKey = value
    }

    /**
     * @param value
     */
    @JvmName("cilawjguedndoyhh")
    public suspend fun customerId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customerId = mapped
    }

    /**
     * @param value
     */
    @JvmName("ldifsporsrixwbwf")
    public suspend fun sharedKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sharedKey = mapped
    }

    internal fun build(): LogAnalyticsConfigurationArgs = LogAnalyticsConfigurationArgs(
        customerId = customerId,
        sharedKey = sharedKey,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/LogAnalyticsConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.LogAnalyticsConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property customerId
 * @property sharedKey
 */
public data class LogAnalyticsConfigurationArgs(
    public val customerId: Output<String>? = null,
    public val sharedKey: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.LogAnalyticsConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.LogAnalyticsConfigurationArgs =
        com.pulumi.azurenative.web.inputs.LogAnalyticsConfigurationArgs.builder()
            .customerId(customerId?.applyValue({ args0 -> args0 }))
            .sharedKey(sharedKey?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LogAnalyticsConfigurationArgs].
 */
@PulumiTagMarker
public class LogAnalyticsConfigurationArgsBuilder internal constructor() {
    private var customerId: Output<String>? = null

    private var sharedKey: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("hjsjgsxidarxssrx")
    public suspend fun customerId(`value`: Output<String>) {
        this.customerId = value
    }

    /**
     * @param value
     */
    @JvmName("wupeqryixywqyytq")
    public suspend fun sharedKey(`value`: Output<String>) {
        this.sharedKey = value
    }

    /**
     * @param value
     */
    @JvmName("mfqutjaqtovneeqo")
    public suspend fun customerId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customerId = mapped
    }

    /**
     * @param value
     */
    @JvmName("xonccwmeoicnlvsq")
    public suspend fun sharedKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sharedKey = mapped
    }

    internal fun build(): LogAnalyticsConfigurationArgs = LogAnalyticsConfigurationArgs(
        customerId = customerId,
        sharedKey = sharedKey,
    )
}
